Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(115)

Unified Diff: components/autofill/core/browser/autofill_data_util.h

Issue 2844463004: Rename card 'type' into 'issuer network.' (Closed)
Patch Set: read -> use Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_data_util.h
diff --git a/components/autofill/core/browser/autofill_data_util.h b/components/autofill/core/browser/autofill_data_util.h
index b71585e326211b59845313f1de66c0076c5d2f50..4add93c09c16bc1f3a3045280ddc0795d65fd796 100644
--- a/components/autofill/core/browser/autofill_data_util.h
+++ b/components/autofill/core/browser/autofill_data_util.h
@@ -5,8 +5,10 @@
#ifndef COMPONENTS_AUTOFILL_CORE_BROWSER_AUTOFILL_DATA_UTIL_H_
#define COMPONENTS_AUTOFILL_CORE_BROWSER_AUTOFILL_DATA_UTIL_H_
+#include <string>
+
#include "base/strings/string16.h"
-#include "base/strings/string_piece.h"
+#include "base/strings/string_piece_forward.h"
#include "components/autofill/core/browser/autofill_profile.h"
namespace autofill {
@@ -18,11 +20,12 @@ struct NameParts {
base::string16 family;
};
// Used to map Chrome card types to Payment Request API basic card payment spec
// types and icons. https://w3c.github.io/webpayments-methods-card/#method-id
struct PaymentRequestData {
- const char* card_type;
- const char* basic_card_payment_type;
+ const char* issuer_network;
+ const char* basic_card_issuer_network;
const int icon_resource_id;
const int a11y_label_resource_id;
};
@@ -53,9 +56,10 @@ bool ProfileMatchesFullName(base::StringPiece16 full_name,
// any unrecognized type.
const PaymentRequestData& GetPaymentRequestData(const std::string& type);
-// Returns the autofill credit card type string for the provided Payment Request
-// API basic card payment spec |type|.
-const char* GetCardTypeForBasicCardPaymentType(const std::string& type);
+// Returns the autofill credit card issuer network string for the provided
+// Payment Request API basic card payment spec |basic_card_card_issuer_network|.
+const char* GetIssuerNetworkForBasicCardIssuerNetwork(
+ const std::string& basic_card_issuer_network);
// Returns whether the specified |country_code| is a valid country code.
bool IsValidCountryCode(const std::string& country_code);
@@ -18,11 +20,12 @@ struct NameParts {
base::string16 family;
};
-// Used to map Chrome card types to Payment Request API basic card payment spec
-// types and icons. https://w3c.github.io/webpayments-methods-card/#method-id
+// Used to map Chrome card issuer networks to Payment Request API basic card
+// payment spec issuer networks and icons.
+// https://w3c.github.io/webpayments-methods-card/#method-id
struct PaymentRequestData {

Powered by Google App Engine
This is Rietveld 408576698